summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrian Cameron <bcameron@src.gnome.org>2001-06-27 16:30:33 +0000
committerBrian Cameron <bcameron@src.gnome.org>2001-06-27 16:30:33 +0000
commit59185576a9845e42286510f2a8264c763da655c3 (patch)
tree724d1f589c4a04af5028a6b0cd87765321d78aaa
parent3519fe9a47c26601cad3c5151c9f5c966dd52e43 (diff)
downloadatk-59185576a9845e42286510f2a8264c763da655c3.tar.gz
Updated AtkXYCoords enum.
-rw-r--r--ChangeLog4
-rwxr-xr-xatk/atktext.h8
2 files changed, 8 insertions, 4 deletions
diff --git a/ChangeLog b/ChangeLog
index a6ad021..c2563b2 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,4 +1,8 @@
2001-06-27 Brian Cameron <brian.cameron@sun.com>
+ *atk/atktext.h
+ Updated AtkXYCoords enum.
+
+2001-06-27 Brian Cameron <brian.cameron@sun.com>
*atk/atkaction.c atk/atkaction.h atk/atkcomponent.c
atk/atkcomponent.h atk/atkhyperlink.c atk/atkhypertext.c
atk/atkimage.c atk/atkimage.h atk/atkobject.c
diff --git a/atk/atktext.h b/atk/atktext.h
index b01ec1e..04c5dca 100755
--- a/atk/atktext.h
+++ b/atk/atktext.h
@@ -51,14 +51,14 @@ typedef struct _AtkTextIface AtkTextIface;
/**
*AtkXYCoords:
*@ATK_XY_SCREEN: specifies xy coordinates relative to the screen
*@ATK_XY_WIDGET: specifies xy coordinates relative to the widgets window
*
- *Specifies what type of coordinates are to be returned for functions that
- *return position coordinates
+ *Specifies how xy coordinates are to be interpreted
**/
typedef enum {
ATK_XY_SCREEN,
- ATK_XY_WIDGET
+ ATK_XY_WINDOW
}AtkXYCoords;
/**
@@ -51,14 +51,14 @@ typedef struct _AtkTextIface AtkTextIface;
*AtkXYCoords:
*@ATK_XY_SCREEN: specifies xy coordinates relative to the screen
- *@ATK_XY_WIDGET: specifies xy coordinates relative to the widgets window
+ *@ATK_XY_WINDOW: specifies xy coordinates relative to the widgets
+ * top-level window
*